@@ -12,7 +12,6 @@ import typing as t
 import libtmux
 import pytest
 from libtmux._internal.query_list import ObjectDoesNotExist
-from libtmux.common import has_gte_version, has_lt_version
 from libtmux.exc import LibTmuxException
 from libtmux.pane import Pane
 from libtmux.session import Session
@@ -79,7 +78,7 @@ def test_split_windows_three_pane(session: Session) -> None:
 
         assert len(session.windows) == window_count
         window_count += 1
-        w.set_window_option("main-pane-height", 50)
+        w.set_option("main-pane-height", 50)
         w.select_layout(wconf["layout"])
 
 
@@ -97,9 +96,9 @@ def test_focus_pane_index(session: Session) -> None:
 
     assert session.active_window.name == "focused window"
 
-    pane_base_index_ = session.active_window.show_window_option(
+    pane_base_index_ = session.active_window.show_option(
         "pane-base-index",
-        g=True,
+        global_=True,
     )
     assert isinstance(pane_base_index_, int)
     pane_base_index = int(pane_base_index_)
@@ -279,10 +278,10 @@ def test_global_session_env_options(
     builder.build(session=session)
 
     visual_silence_ = session.show_option("visual-silence", global_=True)
-    assert isinstance(visual_silence_, str)
-    assert visual_silence in visual_silence_
+    assert isinstance(visual_silence_, bool)
+    assert visual_silence_ is True
     assert repeat_time == session.show_option("repeat-time")
-    assert main_pane_height == session.active_window.show_window_option(
+    assert main_pane_height == session.active_window.show_option(
         "main-pane-height",
     )
 
@@ -296,8 +295,7 @@ def test_window_options(
     )
     workspace = loader.expand(workspace)
 
-    if has_gte_version("2.3"):
-        workspace["windows"][0]["options"]["pane-border-format"] = " #P "
+    workspace["windows"][0]["options"]["pane-border-format"] = " #P "
 
     builder = WorkspaceBuilder(session_config=workspace, server=session.server)
 
@@ -309,9 +307,8 @@ def test_window_options(
             p = p
             assert len(session.windows) == window_count
         assert isinstance(w, Window)
-        assert w.show_window_option("main-pane-height") == 5
-        if has_gte_version("2.3"):
-            assert w.show_window_option("pane-border-format") == " #P "
+        assert w.show_option("main-pane-height") == 5
+        assert w.show_option("pane-border-format") == " #P "
 
         assert len(session.windows) == window_count
         window_count += 1
@@ -386,10 +383,6 @@ def test_window_shell(
         assert w.name != "top"
 
 
-@pytest.mark.skipif(
-    has_lt_version("3.0"),
-    reason="needs -e flag for new-window and split-window introduced in tmux 3.0",
-)
 def test_environment_variables(
     session: Session,
 ) -> None:
@@ -431,58 +424,6 @@ def test_environment_variables(
     assert pane.capture_pane()[1] == "PANE"
 
 
-@pytest.mark.skipif(
-    has_gte_version("3.0"),
-    reason="warnings are not needed for tmux >= 3.0",
-)
-def test_environment_variables_warns_prior_to_tmux_3_0(
-    session: Session,
-    caplog: pytest.LogCaptureFixture,
-) -> None:
-    """Warns when environmental variables cannot be set prior to tmux 3.0."""
-    workspace = ConfigReader._from_file(
-        test_utils.get_workspace_file("workspace/builder/environment_vars.yaml"),
-    )
-    workspace = loader.expand(workspace)
-
-    builder = WorkspaceBuilder(session_config=workspace, server=session.server)
-    builder.build(session)
-
-    # environment on sessions should work as this is done using set-environment
-    # on the session itself
-    assert session.getenv("FOO") == "SESSION"
-    assert session.getenv("PATH") == "/tmp"
-
-    assert (
-        sum(
-            1
-            for record in caplog.records
-            if "Cannot set environment for new windows." in record.message
-        )
-        # From window_overrides and both_overrides, but not
-        # both_overrides_in_first_pane.
-        == 2
-    ), "Warning on creating windows missing"
-    assert (
-        sum(
-            1
-            for record in caplog.records
-            if "Cannot set environment for new panes." in record.message
-        )
-        # From pane_overrides and both_overrides, but not both_overrides_in_first_pane.
-        == 2
-    ), "Warning on creating panes missing"
-    assert (
-        sum(
-            1
-            for record in caplog.records
-            if "Cannot set environment for new panes and windows." in record.message
-        )
-        # From both_overrides_in_first_pane.
-        == 1
-    )
-
-
 def test_automatic_rename_option(
     server: Server,
     monkeypatch: pytest.MonkeyPatch,
@@ -516,7 +457,7 @@ def test_automatic_rename_option(
     assert retry_until(check_window_name_mismatch, 5, interval=0.25)
 
     def check_window_name_match() -> bool:
-        assert w.show_window_option("automatic-rename") == "on"
+        assert w.show_option("automatic-rename") is True
         return w.name in {
             pathlib.Path(os.getenv("SHELL", "bash")).name,
             portable_command,
@@ -656,10 +597,6 @@ def test_start_directory_relative(session: Session, tmp_path: pathlib.Path) -> N
             assert retry_until(f_)
 
 
-@pytest.mark.skipif(
-    has_lt_version("3.2a"),
-    reason="needs format introduced in tmux >= 3.2a",
-)
 def test_start_directory_sets_session_path(server: Server) -> None:
     """Test start_directory setting path in session_path."""
     workspace = ConfigReader._from_file(
@@ -717,7 +654,7 @@ def test_pane_order(session: Session) -> None:
         window_count += 1
 
     for w in session.windows:
-        pane_base_index = w.show_window_option("pane-base-index", g=True)
+        pane_base_index = w.show_option("pane-base-index", global_=True)
         assert pane_base_index is not None
         pane_base_index = int(pane_base_index)
         for p_index, p in enumerate(w.panes, start=pane_base_index):
@@ -1442,10 +1379,6 @@ def test_first_pane_start_directory(session: Session, tmp_path: pathlib.Path) ->
         assert retry_until(f_)
 
 
-@pytest.mark.skipif(
-    has_lt_version("2.9"),
-    reason="needs option introduced in tmux >= 2.9",
-)
 def test_layout_main_horizontal(session: Session) -> None:
     """Test that tmux's main-horizontal layout is used when specified."""
     yaml_workspace = test_utils.get_workspace_file("workspace/builder/three_pane.yaml")
@@ -1523,7 +1456,6 @@ DEFAULT_SIZE_FIXTURES = [
     DEFAULT_SIZE_FIXTURES,
     ids=[f.test_id for f in DEFAULT_SIZE_FIXTURES],
 )
-@pytest.mark.skipif(has_lt_version("2.9"), reason="default-size only applies there")
 def test_issue_800_default_size_many_windows(
     server: Server,
     monkeypatch: pytest.MonkeyPatch,
